==> jc-1.4.0.tar.gz: java/rmi/ConnectIOException.h <==
// public class java.rmi.ConnectIOException

// class file dependencies
// @dep_class 4e0a56550c69d57c java_io_IOException
// @dep_class c5feb325780a6cd7 java_lang_Exception
// @dep_class 2a7152deee1944f1 java_lang_Object
// @dep_class 3be5c3c4fdd59a1e java_lang_Throwable
// @dep_class c9e276a152c0612a java_rmi_ConnectIOException
// @dep_class 512cf355dcdeb26d java_rmi_RemoteException

// header file dependencies
// @dep_header java_rmi_RemoteException

#include "java/rmi/RemoteException.h"

#ifndef _JC_java_rmi_ConnectIOException_H_
#define _JC_java_rmi_ConnectIOException_H_

// Forward structure declarations
struct _jc_java_lang_Class$object;
struct _jc_java_lang_Exception$object;
struct _jc_java_lang_String$object;

// Typedefs
typedef struct _jc_java_rmi_ConnectIOException$sub_refs	_jc_java_rmi_ConnectIOException$sub_refs;
typedef struct _jc_java_rmi_ConnectIOException$sub_nonrefs	_jc_java_rmi_ConnectIOException$sub_nonrefs;
typedef struct _jc_java_rmi_ConnectIOException$refs	_jc_java_rmi_ConnectIOException$refs;
typedef struct _jc_java_rmi_ConnectIOException$nonrefs	_jc_java_rmi_ConnectIOException$nonrefs;
typedef struct _jc_java_rmi_ConnectIOException$object	_jc_java_rmi_ConnectIOException$object;

typedef struct _jc_java_rmi_ConnectIOException$fields_struct	_jc_java_rmi_ConnectIOException$fields_struct;
typedef const struct _jc_java_rmi_ConnectIOException$vmethods	_jc_java_rmi_ConnectIOException$vmethods;
typedef const struct _jc_java_rmi_ConnectIOException$vtable	_jc_java_rmi_ConnectIOException$vtable;
typedef const struct _jc_java_rmi_ConnectIOException$vtype	_jc_java_rmi_ConnectIOException$vtype;

// Class fields structure
struct _jc_java_rmi_ConnectIOException$fields_struct {
	jlong	serialVersionUID;
};
extern _jc_java_rmi_ConnectIOException$fields_struct _jc_java_rmi_ConnectIOException$class_fields;

// Constructors
extern void _jc_java_rmi_ConnectIOException$method$_init$c31b894660454d13(_jc_env *, struct _jc_java_rmi_ConnectIOException$object *, struct _jc_java_lang_String$object *);
extern void _jc_java_rmi_ConnectIOException$method$_init$d27a3a3f2a4ade11(_jc_env *, struct _jc_java_rmi_ConnectIOException$object *, struct _jc_java_lang_String$object *, struct _jc_java_lang_Exception$object *);

// Virtual methods structure
struct _jc_java_rmi_ConnectIOException$vmethods {
};

// Vtable
struct _jc_java_rmi_ConnectIOException$vtable {
	_jc_java_lang_Object$vmethods	java_lang_Object;
	_jc_java_lang_Throwable$vmethods	java_lang_Throwable;
	_jc_java_lang_Exception$vmethods	java_lang_Exception;
	_jc_java_io_IOException$vmethods	java_io_IOException;
	_jc_java_rmi_RemoteException$vmethods	java_rmi_RemoteException;
	_jc_java_rmi_ConnectIOException$vmethods	java_rmi_ConnectIOException;
};

// Vtype
struct _jc_java_rmi_ConnectIOException$vtype {
	_jc_type			type;
	_jc_java_rmi_ConnectIOException$vtable	vtable;
};

// Reference instance fields (subclass)
struct _jc_java_rmi_ConnectIOException$sub_refs {
};

// Reference instance fields (object)
struct _jc_java_rmi_ConnectIOException$refs {
    _jc_java_rmi_ConnectIOException$sub_refs	java_rmi_ConnectIOException;
    _jc_java_rmi_RemoteException$sub_refs	java_rmi_RemoteException;
    _jc_java_io_IOException$sub_refs	java_io_IOException;
    _jc_java_lang_Exception$sub_refs	java_lang_Exception;
    _jc_java_lang_Throwable$sub_refs	java_lang_Throwable;
    _jc_java_lang_Object$sub_refs	java_lang_Object;
};

// Non-reference instance fields (subclass)
struct _jc_java_rmi_ConnectIOException$sub_nonrefs {
};

// Non-reference instance fields (object)
struct _jc_java_rmi_ConnectIOException$nonrefs {
    _jc_java_lang_Object$sub_nonrefs	java_lang_Object;
    _jc_java_lang_Throwable$sub_nonrefs	java_lang_Throwable;
    _jc_java_lang_Exception$sub_nonrefs	java_lang_Exception;
    _jc_java_io_IOException$sub_nonrefs	java_io_IOException;
    _jc_java_rmi_RemoteException$sub_nonrefs	java_rmi_RemoteException;
    _jc_java_rmi_ConnectIOException$sub_nonrefs	java_rmi_ConnectIOException;
};

// Object instance structure
struct _jc_java_rmi_ConnectIOException$object {
	_jc_java_rmi_ConnectIOException$refs	refs[0];
	_jc_word		lockword;
	_jc_java_rmi_ConnectIOException$vtype	*vtype;
	_jc_java_rmi_ConnectIOException$nonrefs	nonrefs;
};

// Type structure
extern _jc_java_rmi_ConnectIOException$vtype _jc_java_rmi_ConnectIOException$type;

// Array types class info structures
_JC_DECL_ARRAYS(java_rmi_ConnectIOException, type);

// java.lang.Class instance
extern struct _jc_java_lang_Class$object _jc_java_rmi_ConnectIOException$class_object;

#endif	/* _JC_java_rmi_ConnectIOException_H_ */

==> jc-1.4.6.tar.gz: java/rmi/ConnectIOException.h <==
// public class java.rmi.ConnectIOException

// class file dependencies
// @dep_class 4e0a56550c69d57c java_io_IOException
// @dep_class c5feb325780a6cd7 java_lang_Exception
// @dep_class 1c4f1fc002fc96e5 java_lang_Object
// @dep_class 3be5c3c4fdd59a1e java_lang_Throwable
// @dep_class c9e276a152c0612a java_rmi_ConnectIOException
// @dep_class 512cf355dcdeb26d java_rmi_RemoteException

// header file dependencies
// @dep_header java_rmi_RemoteException

#include "java/rmi/RemoteException.h"

#ifndef _JC_java_rmi_ConnectIOException_H_
#define _JC_java_rmi_ConnectIOException_H_

// Forward structure declarations
struct _jc_java_lang_Class$object;
struct _jc_java_lang_Exception$object;
struct _jc_java_lang_String$object;

// Typedefs
typedef struct _jc_java_rmi_ConnectIOException$sub_refs	_jc_java_rmi_ConnectIOException$sub_refs;
typedef struct _jc_java_rmi_ConnectIOException$sub_nonrefs	_jc_java_rmi_ConnectIOException$sub_nonrefs;
typedef struct _jc_java_rmi_ConnectIOException$refs	_jc_java_rmi_ConnectIOException$refs;
typedef struct _jc_java_rmi_ConnectIOException$nonrefs	_jc_java_rmi_ConnectIOException$nonrefs;
typedef struct _jc_java_rmi_ConnectIOException$object	_jc_java_rmi_ConnectIOException$object;

typedef struct _jc_java_rmi_ConnectIOException$fields_struct	_jc_java_rmi_ConnectIOException$fields_struct;
typedef const struct _jc_java_rmi_ConnectIOException$vmethods	_jc_java_rmi_ConnectIOException$vmethods;
typedef const struct _jc_java_rmi_ConnectIOException$vtable	_jc_java_rmi_ConnectIOException$vtable;
typedef const struct _jc_java_rmi_ConnectIOException$vtype	_jc_java_rmi_ConnectIOException$vtype;

// Class fields structure
struct _jc_java_rmi_ConnectIOException$fields_struct {
	jlong	serialVersionUID;
};
extern _jc_java_rmi_ConnectIOException$fields_struct _jc_java_rmi_ConnectIOException$class_fields;

// Constructors
extern void _jc_java_rmi_ConnectIOException$method$_init$c31b894660454d13(_jc_env *, struct _jc_java_rmi_ConnectIOException$object *, struct _jc_java_lang_String$object *) _JC_JCNI_ATTR;
extern void _jc_java_rmi_ConnectIOException$method$_init$d27a3a3f2a4ade11(_jc_env *, struct _jc_java_rmi_ConnectIOException$object *, struct _jc_java_lang_String$object *, struct _jc_java_lang_Exception$object *) _JC_JCNI_ATTR;

// Virtual methods structure
struct _jc_java_rmi_ConnectIOException$vmethods {
};

// Vtable
struct _jc_java_rmi_ConnectIOException$vtable {
	_jc_java_lang_Object$vmethods	java_lang_Object;
	_jc_java_lang_Throwable$vmethods	java_lang_Throwable;
	_jc_java_lang_Exception$vmethods	java_lang_Exception;
	_jc_java_io_IOException$vmethods	java_io_IOException;
	_jc_java_rmi_RemoteException$vmethods	java_rmi_RemoteException;
	_jc_java_rmi_ConnectIOException$vmethods	java_rmi_ConnectIOException;
};

// Vtype
struct _jc_java_rmi_ConnectIOException$vtype {
	_jc_type			type;
	_jc_java_rmi_ConnectIOException$vtable	vtable;
};

// Reference instance fields (subclass)
struct _jc_java_rmi_ConnectIOException$sub_refs {
};

// Reference instance fields (object)
struct _jc_java_rmi_ConnectIOException$refs {
    _jc_java_rmi_ConnectIOException$sub_refs	java_rmi_ConnectIOException;
    _jc_java_rmi_RemoteException$sub_refs	java_rmi_RemoteException;
    _jc_java_io_IOException$sub_refs	java_io_IOException;
    _jc_java_lang_Exception$sub_refs	java_lang_Exception;
    _jc_java_lang_Throwable$sub_refs	java_lang_Throwable;
    _jc_java_lang_Object$sub_refs	java_lang_Object;
};

// Non-reference instance fields (subclass)
struct _jc_java_rmi_ConnectIOException$sub_nonrefs {
};

// Non-reference instance fields (object)
struct _jc_java_rmi_ConnectIOException$nonrefs {
    _jc_java_lang_Object$sub_nonrefs	java_lang_Object;
    _jc_java_lang_Throwable$sub_nonrefs	java_lang_Throwable;
    _jc_java_lang_Exception$sub_nonrefs	java_lang_Exception;
    _jc_java_io_IOException$sub_nonrefs	java_io_IOException;
    _jc_java_rmi_RemoteException$sub_nonrefs	java_rmi_RemoteException;
    _jc_java_rmi_ConnectIOException$sub_nonrefs	java_rmi_ConnectIOException;
};

// Object instance structure
struct _jc_java_rmi_ConnectIOException$object {
	_jc_java_rmi_ConnectIOException$refs	refs[0];
	_jc_word		lockword;
	_jc_java_rmi_ConnectIOException$vtype	*vtype;
	_jc_java_rmi_ConnectIOException$nonrefs	nonrefs;
};

// Type structure
extern _jc_java_rmi_ConnectIOException$vtype _jc_java_rmi_ConnectIOException$type;

// Array types class info structures
_JC_DECL_ARRAYS(java_rmi_ConnectIOException, type);

// java.lang.Class instance
extern struct _jc_java_lang_Class$object _jc_java_rmi_ConnectIOException$class_object;

#endif	/* _JC_java_rmi_ConnectIOException_H_ */
